@@ -3,7 +3,7 @@
  * E-table-config.c: The ETable config dialog.
  *
  * Authors:
- *   Chris Lahey (clahey@ximian.com)
+ *   Chris Lahey <clahey@ximian.com>
  *   Miguel de Icaza (miguel@ximian.com)
  *
  * FIXME:
@@ -40,6 +40,11 @@ enum {
 	LAST_SIGNAL
 };
 
+enum {
+	ARG_0,
+	ARG_STATE,
+};
+
 static guint e_table_config_signals [LAST_SIGNAL] = { 0, };
 
 static void
@@ -57,6 +62,21 @@ config_destroy (GtkObject *object)
 	GTK_OBJECT_CLASS (config_parent_class)->destroy (object);
 }
 
+static void
+config_get_arg (GtkObject *o, GtkArg *arg, guint arg_id)
+{
+	ETableConfig *config = E_TABLE_CONFIG (o);
+
+	switch (arg_id){
+	case ARG_STATE:
+		GTK_VALUE_OBJECT (*arg) = (GtkObject *) config->state;
+		break;
+
+	default:
+		break;
+	}
+}
+
 static void
 e_table_config_changed (ETableConfig *config, ETableState *state)
 {
@@ -78,6 +98,7 @@ config_class_init (GtkObjectClass *object_class)
 	
 	klass->changed        = NULL;
 
+	object_class->get_arg = config_get_arg;
 	object_class->destroy = config_destroy;
 
 	e_table_config_signals [CHANGED] =
@@ -89,6 +110,9 @@ config_class_init (GtkObjectClass *object_class)
 				GTK_TYPE_NONE, 0);
 
 	gtk_object_class_add_signals (object_class, e_table_config_signals, LAST_SIGNAL);
+
+	gtk_object_add_arg_type ("ETableConfig::state", E_TABLE_STATE_TYPE,
+				 GTK_ARG_READABLE, ARG_STATE);
 }
 
 static ETableColumnSpecification *
@@ -702,6 +726,12 @@ setup_gui (ETableConfig *config)
 	gtk_signal_connect (
 		GTK_OBJECT (config->dialog_toplevel), "apply",
 		GTK_SIGNAL_FUNC (dialog_apply), config);
+
+	if (!e_table_sort_info_get_can_group (config->state->sort_info)) {
+		GtkWidget *button = glade_xml_get_widget (gui, "button-group");
+		gtk_widget_hide (button);
+		gtk_widget_hide (config->group_label);
+	}
 	
 	gtk_object_unref (GTK_OBJECT (gui));
 }
