@@ -50,8 +50,8 @@
 #define E_ICON_BAR_LARGE_ICON_TEXT_Y	(E_ICON_BAR_LARGE_ICON_HEIGHT + 4)
 
 #define E_ICON_BAR_SMALL_ICON_SPACING	4	/* Spacing between items. */
-#define E_ICON_BAR_SMALL_ICON_WIDTH	24
-#define E_ICON_BAR_SMALL_ICON_HEIGHT	24
+#define E_ICON_BAR_SMALL_ICON_WIDTH	16
+#define E_ICON_BAR_SMALL_ICON_HEIGHT	16
 #define E_ICON_BAR_SMALL_ICON_X		4
 #define E_ICON_BAR_SMALL_ICON_TEXT_X	(E_ICON_BAR_SMALL_ICON_WIDTH + 6)
 
@@ -543,7 +543,6 @@ flatten_alpha (GdkPixbuf *image, guint rgb)
 	if (!image || !gdk_pixbuf_get_has_alpha (image))
 		return NULL;
 
-
 	return gdk_pixbuf_composite_color_simple (
 		image,
 		gdk_pixbuf_get_width (image),
@@ -590,9 +589,9 @@ e_icon_bar_style_set (GtkWidget *widget, GtkStyle *previous_style) {
 		flattened = flatten_alpha (item->pixbuf,
 					   rgb_from_gdk_color (&style->bg [GTK_STATE_NORMAL]));
 
-		gnome_canvas_item_set(item->image, 				      
-				      "GnomeCanvasPixbuf::pixbuf", flattened ? flattened : item->pixbuf,
-				      NULL);
+		gnome_canvas_item_set (item->image, 				      
+				       "GnomeCanvasPixbuf::pixbuf", flattened ? flattened : item->pixbuf,
+				       NULL);
 		gnome_canvas_item_set (item->text,
 				       "font_gdk", style->font,
 				       "fill_color_gdk", &style->fg [GTK_STATE_NORMAL],
@@ -828,15 +827,24 @@ e_icon_bar_set_item_image	(EIconBar	  *icon_bar,
 				 GdkPixbuf	  *image)
 {
 	EIconBarItem *item;
+	GdkPixbuf *flattened;
+	GtkStyle *style = GTK_WIDGET (icon_bar)->style;
 
 	g_return_if_fail (E_IS_ICON_BAR (icon_bar));
 	g_return_if_fail (item_num >= 0);
 	g_return_if_fail (item_num < icon_bar->items->len);
 
 	item = &g_array_index (icon_bar->items, EIconBarItem, item_num);
+
+	flattened = flatten_alpha (item->pixbuf,
+				   rgb_from_gdk_color (&style->bg [GTK_STATE_NORMAL]));
+
 	gnome_canvas_item_set (item->image,
-			       "GnomeCanvasPixbuf::pixbuf", image,
+			       "GnomeCanvasPixbuf::pixbuf", flattened ? flattened : image,
 			       NULL);
+
+	if (flattened)
+		gdk_pixbuf_unref (flattened);
 }
 
 
@@ -880,7 +888,7 @@ e_icon_bar_get_item_text	(EIconBar	  *icon_bar,
 void
 e_icon_bar_set_item_text	(EIconBar	  *icon_bar,
 				 gint		   item_num,
-				 gchar		  *text)
+				 const gchar	  *text)
 {
 	EIconBarItem *item;
 
